searchData={"items":[{"type":"module","title":"DNS","doc":"Documentation for `DNS`.","ref":"DNS.html"},{"type":"function","title":"DNS.to_binary/1","doc":"","ref":"DNS.html#to_binary/1"},{"type":"module","title":"DNS.Class","doc":"# DNS Class\n\n# Note\nAs noted in [RFC6762], Multicast DNS can only carry DNS records with classes in the range 0-32767.\nClasses in the range 32768 to 65535 are incompatible with Multicast DNS.\n\n# Note\nWhen this registry is modified, the YANG module [iana-dns-class-rr-type]\nmust be updated as defined in [RFC9108].\n\n    Decimal \tHex \tRegistration Procedures \tNote\n    0\t0x0000\tStandards Action\n    1-127\t0x0000-0x007F\tIETF Review\tdata CLASSes only\n    128-253\t0x0080-0x00FD\tIETF Review\tQCLASSes and meta-CLASSes only\n    256-32767\t0x0100-0x7FFF\tIETF Review\n    32768-57343\t0x8000-0xDFFF\tSpecification Required\tdata CLASSes only\n    57344-65279\t0xE000-0xFEFF\tSpecification Required\tQCLASSes and meta-CLASSes only\n    65280-65534\t0xFF00-0xFFFE\tPrivate Use\n    65535\t0xFFFF\tStandards Action\n\n    Decimal \tHexadecimal \tName \tReference\n    0\t0x0000\tReserved\t[RFC6895]\n    1\t0x0001\tInternet (IN)\t[RFC1035]\n    2\t0x0002\tUnassigned\n    3\t0x0003\tChaos (CH)\t[D. Moon, \"Chaosnet\", A.I. Memo 628, Massachusetts Institute of Technology Artificial Intelligence Laboratory, June 1981.]\n    4\t0x0004\tHesiod (HS)\t[Dyer, S., and F. Hsu, \"Hesiod\", Project Athena Technical Plan - Name Service, April 1987.]\n    5-253\t0x0005-0x00FD\tUnassigned\n    254\t0x00FE\tQCLASS NONE\t[RFC2136]\n    255\t0x00FF\tQCLASS * (ANY)\t[RFC1035]\n    256-65279\t0x0100-0xFEFF\tUnassigned\n    65280-65534\t0xFF00-0xFFFE\tReserved for Private Use\t[RFC6895]\n    65535\t0xFFFF\tReserved\t[RFC6895]\n\n# Reference\n- [iana](https://www.iana.org/assignments/dns-parameters/dns-parameters.xhtml#dns-parameters-2)\n- [Domain Name System (DNS) IANA Considerations](https://tools.ietf.org/html/rfc6895)\n- [YANG Types for DNS Classes and Resource Record Types](https://tools.ietf.org/html/rfc9108)","ref":"DNS.Class.html"},{"type":"function","title":"DNS.Class.chaos/0","doc":"# Chaos (CH)","ref":"DNS.Class.html#chaos/0"},{"type":"function","title":"DNS.Class.hesiod/0","doc":"# Hesiod (HS)","ref":"DNS.Class.html#hesiod/0"},{"type":"function","title":"DNS.Class.internet/0","doc":"# Internet (IN)","ref":"DNS.Class.html#internet/0"},{"type":"function","title":"DNS.Class.new/1","doc":"# Create a new Class struct","ref":"DNS.Class.html#new/1"},{"type":"function","title":"DNS.Class.qclass_any/0","doc":"# QCLASS * (ANY)","ref":"DNS.Class.html#qclass_any/0"},{"type":"function","title":"DNS.Class.qclass_none/0","doc":"# QCLASS NONE","ref":"DNS.Class.html#qclass_none/0"},{"type":"function","title":"DNS.Class.reserved/0","doc":"# Reserved","ref":"DNS.Class.html#reserved/0"},{"type":"type","title":"DNS.Class.t/0","doc":"","ref":"DNS.Class.html#t:t/0"},{"type":"module","title":"DNS.Message","doc":"# DNS Message\n\nAll communications inside of the domain protocol are carried in a single\nformat called a message.  The top level format of message is divided\ninto 5 sections (some of which are empty in certain cases) shown below:\n\n    +---------------------+\n    |        Header       |\n    +---------------------+\n    |       Question      | the question for the name server\n    +---------------------+\n    |        Answer       | RRs answering the question\n    +---------------------+\n    |      Authority      | RRs pointing toward an authority\n    +---------------------+\n    |      Additional     | RRs holding additional information\n    +---------------------+\n\nThe header section is always present.  The header includes fields that\nspecify which of the remaining sections are present, and also specify\nwhether the message is a query or a response, a standard query or some\nother opcode, etc.\n\nThe names of the sections after the header are derived from their use in\nstandard queries.  The question section contains fields that describe a\nquestion to a name server.  These fields are a query type (QTYPE), a\nquery class (QCLASS), and a query domain name (QNAME).  The last three\nsections have the same format: a possibly empty list of concatenated\nresource records (RRs).  The answer section contains RRs that answer the\nquestion; the authority section contains RRs that point toward an\nauthoritative name server; the additional records section contains RRs\nwhich relate to the query, but are not strictly answers for the\nquestion.","ref":"DNS.Message.html"},{"type":"function","title":"DNS.Message.from_binary/1","doc":"","ref":"DNS.Message.html#from_binary/1"},{"type":"function","title":"DNS.Message.new/0","doc":"","ref":"DNS.Message.html#new/0"},{"type":"type","title":"DNS.Message.t/0","doc":"","ref":"DNS.Message.html#t:t/0"},{"type":"module","title":"DNS.Message.Domain","doc":"# DNS Domain","ref":"DNS.Message.Domain.html"},{"type":"function","title":"DNS.Message.Domain.from_binary/2","doc":"Get name from bitstring, uncompress name in message","ref":"DNS.Message.Domain.html#from_binary/2"},{"type":"function","title":"DNS.Message.Domain.new/1","doc":"","ref":"DNS.Message.Domain.html#new/1"},{"type":"function","title":"DNS.Message.Domain.new/2","doc":"","ref":"DNS.Message.Domain.html#new/2"},{"type":"type","title":"DNS.Message.Domain.t/0","doc":"","ref":"DNS.Message.Domain.html#t:t/0"},{"type":"module","title":"DNS.Message.EDNS0","doc":"# EDNS0 moudle\nEDNS0 is defined in [RFC6891](https://datatracker.ietf.org/doc/html/rfc6891)\n\nWhen Message additional section includes a record with type 41,\nit is the OPT pseudo-RR, which includes EDNS0 information.\n\nAn OPT pseudo-RR (sometimes called a meta-RR) MAY be added to the\nadditional data section of a request.\n\nThe OPT RR has RR type 41.\n\nIf an OPT record is present in a received request, compliant\nresponders MUST include an OPT record in their respective responses.\n\nAn OPT record does not carry any DNS data.  It is used only to\ncontain control information pertaining to the question-and-answer\nsequence of a specific transaction.  OPT RRs MUST NOT be cached,\nforwarded, or stored in or loaded from master files.\n\nThe OPT RR MAY be placed anywhere within the additional data section.\nWhen an OPT RR is included within any DNS message, it MUST be the\nonly OPT RR in that message.  If a query message with more than one\nOPT RR is received, a FORMERR (RCODE=1) MUST be returned.  The\nplacement flexibility for the OPT RR does not override the need for\nthe TSIG or SIG(0) RRs to be the last in the additional section\nwhenever they are present.\n\nThe fixed part of an OPT RR is structured as follows:\n\n     +------------+--------------+------------------------------+\n     | Field Name | Field Type   | Description                  |\n     +------------+--------------+------------------------------+\n     | NAME       | domain name  | MUST be 0 (root domain)      |\n     | TYPE       | u_int16_t    | OPT (41)                     |\n     | CLASS      | u_int16_t    | requestor's UDP payload size |\n     | TTL        | u_int32_t    | extended RCODE and flags     |\n     | RDLEN      | u_int16_t    | length of all RDATA          |\n     | RDATA      | octet stream | {attribute,value} pairs      |\n     +------------+--------------+------------------------------+\n\nThe extended RCODE and flags, which OPT stores in the RR Time to Live\n(TTL) field, are structured as follows:\n\n                    +0 (MSB)                            +1 (LSB)\n        +---+---+---+---+---+---+---+---+---+---+---+---+---+---+---+---+\n     0: |         EXTENDED-RCODE        |            VERSION            |\n        +---+---+---+---+---+---+---+---+---+---+---+---+---+---+---+---+\n     2: | DO|                           Z                               |\n        +---+---+---+---+---+---+---+---+---+---+---+---+---+---+---+---+","ref":"DNS.Message.EDNS0.html"},{"type":"module","title":"EXTENDED-RCODE - DNS.Message.EDNS0","doc":"Forms the upper 8 bits of extended 12-bit RCODE (together with the\n4 bits defined in [RFC1035].  Note that EXTENDED-RCODE value 0\nindicates that an unextended RCODE is in use (values 0 through\n15).","ref":"DNS.Message.EDNS0.html#module-extended-rcode"},{"type":"module","title":"VERSION - DNS.Message.EDNS0","doc":"Indicates the implementation level of the setter.  Full\nconformance with this specification is indicated by version '0'.\nRequestors are encouraged to set this to the lowest implemented\nlevel capable of expressing a transaction, to minimise the\nresponder and network load of discovering the greatest common\nimplementation level between requestor and responder.  A\nrequestor's version numbering strategy MAY ideally be a run-time\nconfiguration option.\n\nIf a responder does not implement the VERSION level of the\nrequest, then it MUST respond with RCODE=BADVERS.  All responses\nMUST be limited in format to the VERSION level of the request, but\nthe VERSION of each response SHOULD be the highest implementation\nlevel of the responder.  In this way, a requestor will learn the\nimplementation level of a responder as a side effect of every\nresponse, including error responses and including RCODE=BADVERS.","ref":"DNS.Message.EDNS0.html#module-version"},{"type":"module","title":"DO - DNS.Message.EDNS0","doc":"DNSSEC OK bit as defined by [RFC3225].","ref":"DNS.Message.EDNS0.html#module-do"},{"type":"module","title":"Z - DNS.Message.EDNS0","doc":"Set to zero by senders and ignored by receivers, unless modified\nin a subsequent specification.\n\nThe variable part of an OPT RR may contain zero or more options in\nthe RDATA.  Each option MUST be treated as a bit field.  Each option\nis encoded as:\n\n                    +0 (MSB)                            +1 (LSB)\n        +---+---+---+---+---+---+---+---+---+---+---+---+---+---+---+---+\n     0: |                          OPTION-CODE                          |\n        +---+---+---+---+---+---+---+---+---+---+---+---+---+---+---+---+\n     2: |                         OPTION-LENGTH                         |\n        +---+---+---+---+---+---+---+---+---+---+---+---+---+---+---+---+\n     4: |                                                               |\n        /                          OPTION-DATA                          /\n        /                                                               /\n        +---+---+---+---+---+---+---+---+---+---+---+---+---+---+---+---+","ref":"DNS.Message.EDNS0.html#module-z"},{"type":"module","title":"OPTION-CODE - DNS.Message.EDNS0","doc":"Assigned by the Expert Review process as defined by the DNSEXT\nworking group and the IESG.","ref":"DNS.Message.EDNS0.html#module-option-code"},{"type":"module","title":"OPTION-LENGTH - DNS.Message.EDNS0","doc":"Size (in octets) of OPTION-DATA.","ref":"DNS.Message.EDNS0.html#module-option-length"},{"type":"module","title":"OPTION-DATA - DNS.Message.EDNS0","doc":"Varies per OPTION-CODE.  MUST be treated as a bit field.\n\nThe order of appearance of option tuples is not defined.  If one\noption modifies the behaviour of another or multiple options are\nrelated to one another in some way, they have the same effect\nregardless of ordering in the RDATA wire encoding.\n\nAny OPTION-CODE values not understood by a responder or requestor\nMUST be ignored.  Specifications of such options might wish to\ninclude some kind of signaled acknowledgement.  For example, an\noption specification might say that if a responder sees and supports\noption XYZ, it MUST include option XYZ in its response.","ref":"DNS.Message.EDNS0.html#module-option-data"},{"type":"function","title":"DNS.Message.EDNS0.add_option/3","doc":"","ref":"DNS.Message.EDNS0.html#add_option/3"},{"type":"function","title":"DNS.Message.EDNS0.from_binary/1","doc":"","ref":"DNS.Message.EDNS0.html#from_binary/1"},{"type":"function","title":"DNS.Message.EDNS0.is_opt/1","doc":"","ref":"DNS.Message.EDNS0.html#is_opt/1"},{"type":"function","title":"DNS.Message.EDNS0.new/0","doc":"","ref":"DNS.Message.EDNS0.html#new/0"},{"type":"type","title":"DNS.Message.EDNS0.t/0","doc":"","ref":"DNS.Message.EDNS0.html#t:t/0"},{"type":"function","title":"DNS.Message.EDNS0.to_binary/1","doc":"Converts a Record struct to binary data.","ref":"DNS.Message.EDNS0.html#to_binary/1"},{"type":"function","title":"DNS.Message.EDNS0.to_print/1","doc":"","ref":"DNS.Message.EDNS0.html#to_print/1"},{"type":"module","title":"DNS.Message.EDNS0.Option","doc":"DNS EDNS0 Option Codes (OPT)\n\n      0\tReserved\t\t[RFC6891](https://datatracker.ietf.org/doc/html/rfc6891)\n      1\tLLQ\tOptional\t[RFC8764](https://datatracker.ietf.org/doc/html/rfc8764)\n      2\tUpdate Lease\tStandard\t[RFC-ietf-dnssd-update-lease-08]\n      3\tNSID\tStandard\t[RFC5001](https://datatracker.ietf.org/doc/html/rfc5001)\n      4\tReserved\t\t[draft-cheshire-edns0-owner-option]\n      5\tDAU\tStandard\t[RFC6975](https://datatracker.ietf.org/doc/html/rfc6975)\n      6\tDHU\tStandard\t[RFC6975](https://datatracker.ietf.org/doc/html/rfc6975)\n      7\tN3U\tStandard\t[RFC6975](https://datatracker.ietf.org/doc/html/rfc6975)\n      8\tedns-client-subnet\tOptional\t[RFC7871](https://datatracker.ietf.org/doc/html/rfc7871)\n      9\tEDNS EXPIRE\tOptional\t[RFC7314](https://datatracker.ietf.org/doc/html/rfc7314)\n      10\tCOOKIE\tStandard\t[RFC7873](https://datatracker.ietf.org/doc/html/rfc7873)\n      11\tedns-tcp-keepalive\tStandard\t[RFC7828](https://datatracker.ietf.org/doc/html/rfc7828)\n      12\tPadding\tStandard\t[RFC7830](https://datatracker.ietf.org/doc/html/rfc7830)\n      13\tCHAIN\tStandard\t[RFC7901](https://datatracker.ietf.org/doc/html/rfc7901)\n      14\tedns-key-tag\tOptional\t[RFC8145](https://datatracker.ietf.org/doc/html/rfc8145)\n      15\tExtended DNS Error\tStandard\t[RFC8914](https://datatracker.ietf.org/doc/html/rfc8914)\n      16\tEDNS-Client-Tag\tOptional\t[draft-bellis-dnsop-edns-tags]\n      17\tEDNS-Server-Tag\tOptional\t[draft-bellis-dnsop-edns-tags]\n      18\tReport-Channel\tStandard\t[RFC9567](https://datatracker.ietf.org/doc/html/rfc9567)\n      19-20291\tUnassigned\n      20292\tUmbrella Ident\tOptional\t[https://developer.cisco.com/docs/cloud-security/#!integrating-network-devices/rdata-description][Cisco_CIE_DNS_team]\n      20293-26945\tUnassigned\n      26946\tDeviceID\tOptional\t[https://developer.cisco.com/docs/cloud-security/#!network-devices-getting-started/response-codes][Cisco_CIE_DNS_team]\n      26947-65000\tUnassigned\n      65001-65534\tReserved for Local/Experimental Use\t\t[RFC6891](https://datatracker.ietf.org/doc/html/rfc6891)\n      65535\tReserved for future expansion\t\t[RFC6891](https://datatracker.ietf.org/doc/html/rfc6891)","ref":"DNS.Message.EDNS0.Option.html"},{"type":"function","title":"DNS.Message.EDNS0.Option.encode/2","doc":"","ref":"DNS.Message.EDNS0.Option.html#encode/2"},{"type":"function","title":"DNS.Message.EDNS0.Option.parse/2","doc":"Parse Option","ref":"DNS.Message.EDNS0.Option.html#parse/2"},{"type":"function","title":"8\tedns-client-subnet - DNS.Message.EDNS0.Option.parse/2","doc":"+0 (MSB)                            +1 (LSB)\n          +---+---+---+---+---+---+---+---+---+---+---+---+---+---+---+---+\n       0: |                          OPTION-CODE                          |\n          +---+---+---+---+---+---+---+---+---+---+---+---+---+---+---+---+\n       2: |                         OPTION-LENGTH                         |\n          +---+---+---+---+---+---+---+---+---+---+---+---+---+---+---+---+\n       4: |                            FAMILY                             |\n          +---+---+---+---+---+---+---+---+---+---+---+---+---+---+---+---+\n       6: |     SOURCE PREFIX-LENGTH      |     SCOPE PREFIX-LENGTH       |\n          +---+---+---+---+---+---+---+---+---+---+---+---+---+---+---+---+\n       8: |                           ADDRESS...                          /\n          +---+---+---+---+---+---+---+---+---+---+---+---+---+---+---+---+","ref":"DNS.Message.EDNS0.Option.html#parse/2-8-edns-client-subnet"},{"type":"function","title":"DNS.Message.EDNS0.Option.to_print/1","doc":"","ref":"DNS.Message.EDNS0.Option.html#to_print/1"},{"type":"module","title":"DNS.Message.Header","doc":"# DNS Header\n\nThe header contains the following fields:\n\n                                    1  1  1  1  1  1\n      0  1  2  3  4  5  6  7  8  9  0  1  2  3  4  5\n    +--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+\n    |                      ID                       |\n    +--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+\n    |QR|   Opcode  |AA|TC|RD|RA|   Z    |   RCODE   |\n    +--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+\n    |                    QDCOUNT                    |\n    +--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+\n    |                    ANCOUNT                    |\n    +--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+\n    |                    NSCOUNT                    |\n    +--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+\n    |                    ARCOUNT                    |\n    +--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+\n\nwhere:\n\n- `ID`\n\nA 16 bit identifier assigned by the program that\ngenerates any kind of query.  This identifier is copied\nthe corresponding reply and can be used by the requester\nto match up replies to outstanding queries.\n\n- `QR`\n\nA one bit field that specifies whether this message is a\nquery (0), or a response (1).\n\n- `OPCODE`\n\nA four bit field that specifies kind of query in this\nmessage.  This value is set by the originator of a query\nand copied into the response.\n\n- `AA`\n\nAuthoritative Answer - this bit is valid in responses,\nand specifies that the responding name server is an\nauthority for the domain name in question section.\n\nNote that the contents of the answer section may have\nmultiple owner names because of aliases.  The AA bit\ncorresponds to the name which matches the query name, or\nthe first owner name in the answer section.\n\n- `TC`\n\nTrunCation - specifies that this message was truncated\ndue to length greater than that permitted on the\ntransmission channel.\n\n- `RD`\n\nRecursion Desired - this bit may be set in a query and\nis copied into the response.  If RD is set, it directs\nthe name server to pursue the query recursively.\nRecursive query support is optional.\n\n- `RA`\n\nRecursion Available - this be is set or cleared in a\nresponse, and denotes whether recursive query support is\navailable in the name server.\n\n- `Z`\n\nReserved for future use.  Must be zero in all queries\nand responses.\n\n- `AD`\n\nThe AD bit exists in order to provide a means for a security-aware\nresolver to signal to a security-aware name server that the resolver\nconsiders authentic data to be more important than unauthenticated\ndata.  The AD bit is only intended to provide a signal from the\nresolver to the name server; it is not intended to provide a signal\nfrom the name server to the resolver.\n\n[rfc4035]\n\n- `CD`\n\nThe CD bit exists in order to allow a security-aware resolver to\ndisable signature validation in a security-aware name server's\nprocessing of a particular query.\n\n[rfc4035]\n\n- `RCODE`\n\nResponse code - this 4 bit field is set as part of\nresponses.\n\n- `QDCOUNT`\n\nan unsigned 16 bit integer specifying the number of\nentries in the question section.\n\n- `ANCOUNT`\n\nan unsigned 16 bit integer specifying the number of\nresource records in the answer section.\n\n- `NSCOUNT`\n\nan unsigned 16 bit integer specifying the number of name\nserver resource records in the authority records\nsection.\n\n- `ARCOUNT`\n\nan unsigned 16 bit integer specifying the number of\nresource records in the additional records section.\n\n\n# Reference\n- [iana](https://www.iana.org/assignments/dns-parameters/dns-parameters.xhtml#dns-parameters-5)\n- [DOMAIN NAMES - IMPLEMENTATION AND SPECIFICATION](https://tools.ietf.org/html/rfc1035)\n- [Domain Name System (DNS) IANA Considerations](https://tools.ietf.org/html/rfc6895)","ref":"DNS.Message.Header.html"},{"type":"function","title":"DNS.Message.Header.ancount/1","doc":"","ref":"DNS.Message.Header.html#ancount/1"},{"type":"function","title":"DNS.Message.Header.arcount/1","doc":"","ref":"DNS.Message.Header.html#arcount/1"},{"type":"function","title":"DNS.Message.Header.generate_id/0","doc":"","ref":"DNS.Message.Header.html#generate_id/0"},{"type":"function","title":"DNS.Message.Header.new/0","doc":"","ref":"DNS.Message.Header.html#new/0"},{"type":"function","title":"DNS.Message.Header.nscount/1","doc":"","ref":"DNS.Message.Header.html#nscount/1"},{"type":"function","title":"DNS.Message.Header.qdcount/1","doc":"","ref":"DNS.Message.Header.html#qdcount/1"},{"type":"type","title":"DNS.Message.Header.t/0","doc":"","ref":"DNS.Message.Header.html#t:t/0"},{"type":"module","title":"DNS.Message.OpCode","doc":"# DNS OpCode\n\n    OpCode \tName \tReference\n    0\tQuery\t[RFC1035]\n    1\tIQuery (Inverse Query, OBSOLETE)\t[RFC3425]\n    2\tStatus\t[RFC1035]\n    3\tUnassigned\n    4\tNotify\t[RFC1996]\n    5\tUpdate\t[RFC2136]\n    6\tDNS Stateful Operations (DSO)\t[RFC8490]\n    7-15\tUnassigned\n\n# Reference\n- [iana](https://www.iana.org/assignments/dns-parameters/dns-parameters.xhtml#dns-parameters-5)\n- [DOMAIN NAMES - IMPLEMENTATION AND SPECIFICATION](https://tools.ietf.org/html/rfc1035)\n- [Domain Name System (DNS) IANA Considerations](https://tools.ietf.org/html/rfc6895)","ref":"DNS.Message.OpCode.html"},{"type":"function","title":"DNS.Message.OpCode.dso/0","doc":"# dso is a non-standard extension to DNS that is used by the\n[DNS Stateful Operations (DSO)](https://tools.ietf.org/html/draft-sekar-dns-ultradns-00)","ref":"DNS.Message.OpCode.html#dso/0"},{"type":"function","title":"DNS.Message.OpCode.iquery/0","doc":"# iquery is a non-standard extension to DNS that is used by the\n[DNS Zone Transfer Protocol](https://tools.ietf.org/html/rfc1996)","ref":"DNS.Message.OpCode.html#iquery/0"},{"type":"function","title":"DNS.Message.OpCode.new/1","doc":"","ref":"DNS.Message.OpCode.html#new/1"},{"type":"function","title":"DNS.Message.OpCode.notify/0","doc":"# notify is a non-standard extension to DNS that is used by the\n[DNS Zone Transfer Protocol](https://tools.ietf.org/html/rfc1996)","ref":"DNS.Message.OpCode.html#notify/0"},{"type":"function","title":"DNS.Message.OpCode.query/0","doc":"# query is a standard query\n[RFC1035](https://tools.ietf.org/html/rfc1035)","ref":"DNS.Message.OpCode.html#query/0"},{"type":"function","title":"DNS.Message.OpCode.status/0","doc":"# status is a non-standard extension to DNS that is used by the\n[DNS Zone Transfer Protocol](https://tools.ietf.org/html/rfc1996)","ref":"DNS.Message.OpCode.html#status/0"},{"type":"type","title":"DNS.Message.OpCode.t/0","doc":"","ref":"DNS.Message.OpCode.html#t:t/0"},{"type":"function","title":"DNS.Message.OpCode.update/0","doc":"# update is a non-standard extension to DNS that is used by the\n[Dynamic DNS Update](https://tools.ietf.org/html/rfc2136)","ref":"DNS.Message.OpCode.html#update/0"},{"type":"module","title":"DNS.Message.Question","doc":"# DNS Question","ref":"DNS.Message.Question.html"},{"type":"function","title":"DNS.Message.Question.from_binary/2","doc":"","ref":"DNS.Message.Question.html#from_binary/2"},{"type":"function","title":"DNS.Message.Question.list_from_message/1","doc":"","ref":"DNS.Message.Question.html#list_from_message/1"},{"type":"function","title":"DNS.Message.Question.list_from_message/2","doc":"","ref":"DNS.Message.Question.html#list_from_message/2"},{"type":"function","title":"DNS.Message.Question.list_to_binary/1","doc":"","ref":"DNS.Message.Question.html#list_to_binary/1"},{"type":"function","title":"DNS.Message.Question.new/3","doc":"","ref":"DNS.Message.Question.html#new/3"},{"type":"type","title":"DNS.Message.Question.t/0","doc":"","ref":"DNS.Message.Question.html#t:t/0"},{"type":"module","title":"DNS.Message.RCode","doc":"# DNS RCode\nDNS return code\n\nIt would appear from the DNS header that only four bits of\nRCODE, or response/error code, are available.  However, RCODEs can\nappear not only at the top level of a DNS response but also inside\nTSIG RRs [RFC2845], TKEY RRs [RFC2930], and extended by OPT RRs\n[RFC6891].  The OPT RR provides an 8-bit extension to the 4 header\nbits, resulting in a 12-bit RCODE field, and the TSIG and TKEY RRs\nhave a 16-bit field designated in their RFCs as the \"Error\" field.\n\nError codes appearing in the DNS header and in these other RR types\nall refer to the same error code space with the exception of error\ncode 16, which has a different meaning in the OPT RR than in the TSIG\nRR, and error code 9, whose variations are described after the table\nbelow.  The duplicate assignment of 16 was accidental.  To the extent\nthat any prior RFCs imply any sort of different error number space\nfor the OPT, TSIG, or TKEY RRs, they are superseded by this unified\nDNS error number space.  (This paragraph is the reason this document\nupdates [RFC2845] and [RFC2930].)  With the existing exceptions of\nerror numbers 9 and 16, the same error number must not be assigned\nfor different errors even if they would only occur in different RR\ntypes.  See table below.\n\n    Range \tRegistration Procedures\n    0-3840\tIETF Review\n    3841-4095\tPrivate Use\n    4096-65534\tIETF Review\n    65535\tReserved (Standards Action)\n\n    RCODE \tName \tDescription \tReference\n    0\tNoError\tNo Error\t[RFC1035]\n    1\tFormErr\tFormat Error\t[RFC1035]\n    2\tServFail\tServer Failure\t[RFC1035]\n    3\tNXDomain\tNon-Existent Domain\t[RFC1035]\n    4\tNotImp\tNot Implemented\t[RFC1035]\n    5\tRefused\tQuery Refused\t[RFC1035]\n    6\tYXDomain\tName Exists when it should not\t[RFC2136][RFC6672]\n    7\tYXRRSet\tRR Set Exists when it should not\t[RFC2136]\n    8\tNXRRSet\tRR Set that should exist does not\t[RFC2136]\n    9\tNotAuth\tServer Not Authoritative for zone\t[RFC2136]\n    9\tNotAuth\tNot Authorized\t[RFC8945]\n    10\tNotZone\tName not contained in zone\t[RFC2136]\n    11\tDSOTYPENI\tDSO-TYPE Not Implemented\t[RFC8490]\n    12-15\tUnassigned\n    16\tBADVERS\tBad OPT Version\t[RFC6891]\n    16\tBADSIG\tTSIG Signature Failure\t[RFC8945]\n    17\tBADKEY\tKey not recognized\t[RFC8945]\n    18\tBADTIME\tSignature out of time window\t[RFC8945]\n    19\tBADMODE\tBad TKEY Mode\t[RFC2930]\n    20\tBADNAME\tDuplicate key name\t[RFC2930]\n    21\tBADALG\tAlgorithm not supported\t[RFC2930]\n    22\tBADTRUNC\tBad Truncation\t[RFC8945]\n    23\tBADCOOKIE\tBad/missing Server Cookie\t[RFC7873]\n    24-3840\tUnassigned\n    3841-4095\tReserved for Private Use\t\t[RFC6895]\n    4096-65534\tUnassigned\n    65535\tReserved, can be allocated by Standards Action\t\t[RFC6895]\n\n# Reference\n- [iana](https://www.iana.org/assignments/dns-parameters/dns-parameters.xhtml#dns-parameters-6)\n- [DOMAIN NAMES - IMPLEMENTATION AND SPECIFICATION](https://tools.ietf.org/html/rfc1035)\n- [Domain Name System (DNS) IANA Considerations](https://tools.ietf.org/html/rfc6895)","ref":"DNS.Message.RCode.html"},{"type":"function","title":"DNS.Message.RCode.extend/2","doc":"","ref":"DNS.Message.RCode.html#extend/2"},{"type":"function","title":"DNS.Message.RCode.new/1","doc":"","ref":"DNS.Message.RCode.html#new/1"},{"type":"type","title":"DNS.Message.RCode.t/0","doc":"","ref":"DNS.Message.RCode.html#t:t/0"},{"type":"module","title":"DNS.Message.Record","doc":"Record is a struct that represents a DNS resource record.\n\n  All RRs have the same top level format shown below:\n\n  ```txt\n                                      1  1  1  1  1  1\n        0  1  2  3  4  5  6  7  8  9  0  1  2  3  4  5\n      +--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+\n      |                                               |\n      /                                               /\n      /                      NAME                     /\n      |                                               |\n      +--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+\n      |                      TYPE                     |\n      +--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+\n      |                     CLASS                     |\n      +--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+\n      |                      TTL                      |\n      |                                               |\n      +--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+\n      |                   RDLENGTH                    |\n      +--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--|\n      /                     RDATA                     /\n      /                                               /\n      +--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+\n  ```\n\n  where:\n\n  NAME            an owner name, i.e., the name of the node to which this\n                  resource record pertains.\n\n  TYPE            two octets containing one of the RR TYPE codes.\n\n  CLASS           two octets containing one of the RR CLASS codes.\n\n  TTL             a 32 bit signed integer that specifies the time interval\n                  that the resource record may be cached before the source\n                  of the information should again be consulted.  Zero\n                  values are interpreted to mean that the RR can only be\n                  used for the transaction in progress, and should not be\n                  cached.  For example, SOA records are always distributed\n                  with a zero TTL to prohibit caching.  Zero values can\n                  also be used for extremely volatile data.\n\n  RDLENGTH        an unsigned 16 bit integer that specifies the length in\n                  octets of the RDATA field.\n\n  RDATA           a variable length string of octets that describes the\n                  resource.  The format of this information varies\n                  according to the TYPE and CLASS of the resource record.","ref":"DNS.Message.Record.html"},{"type":"function","title":"DNS.Message.Record.from_binary/2","doc":"","ref":"DNS.Message.Record.html#from_binary/2"},{"type":"function","title":"DNS.Message.Record.list_from_message/3","doc":"","ref":"DNS.Message.Record.html#list_from_message/3"},{"type":"function","title":"DNS.Message.Record.new/5","doc":"","ref":"DNS.Message.Record.html#new/5"},{"type":"type","title":"DNS.Message.Record.t/0","doc":"","ref":"DNS.Message.Record.html#t:t/0"},{"type":"module","title":"DNS.Message.Recrod.Data","doc":"","ref":"DNS.Message.Recrod.Data.html"},{"type":"function","title":"DNS.Message.Recrod.Data.new/4","doc":"","ref":"DNS.Message.Recrod.Data.html#new/4"},{"type":"type","title":"DNS.Message.Recrod.Data.t/0","doc":"","ref":"DNS.Message.Recrod.Data.html#t:t/0"},{"type":"protocol","title":"DNS.Message.RecrodData","doc":"","ref":"DNS.Message.RecrodData.html"},{"type":"type","title":"DNS.Message.RecrodData.t/0","doc":"All the types that implement this protocol.","ref":"DNS.Message.RecrodData.html#t:t/0"},{"type":"function","title":"DNS.Message.RecrodData.to_binary/1","doc":"","ref":"DNS.Message.RecrodData.html#to_binary/1"},{"type":"protocol","title":"DNS.Parameter","doc":"","ref":"DNS.Parameter.html"},{"type":"type","title":"DNS.Parameter.t/0","doc":"All the types that implement this protocol.","ref":"DNS.Parameter.html#t:t/0"},{"type":"function","title":"DNS.Parameter.to_binary/1","doc":"","ref":"DNS.Parameter.html#to_binary/1"},{"type":"module","title":"DNS.ResourceRecordType","doc":"# DNS RRTypes\nDNS Resource Record Type\n\n    Decimal \tHex \tRegistration Procedures \tNote\n    0\t0x0000\tRRTYPE zero is used as a special indicator for the SIG RR [RFC2931], [RFC4034] and in other circumstances and must never be allocated for ordinary use.\n    1-127\t0x0000-0x007F\tExpert Review (see mailing list information in [RFC6895]) or Standards Action\tdata TYPEs\n    128-255\t0x0080-0x00FF\tExpert Review (see mailing list information in [RFC6895]) or Standards Action\tQ TYPEs, Meta TYPEs\n    256-61439\t0x0100-0xEFFF\tExpert Review (see mailing list information in [RFC6895]) or Standards Action\tdata RRTYPEs\n    61440-65279\t0xF000-0xFEFF\tReserved for future use (IETF Review required to define use)\n    65280-65534\t0xFF00-0xFFFE\tPrivate Use\n    65535\t0xFFFF\tReserved (Standards Action)\n\n    TYPE \tValue \tMeaning \tReference \tTemplate \tRegistration Date\n    Reserved\t0\t\t[RFC6895]\t\t2021-03-08\n    A\t1\ta host address\t[RFC1035]\n    NS\t2\tan authoritative name server\t[RFC1035]\n    MD\t3\ta mail destination (OBSOLETE - use MX)\t[RFC1035]\n    MF\t4\ta mail forwarder (OBSOLETE - use MX)\t[RFC1035]\n    CNAME\t5\tthe canonical name for an alias\t[RFC1035]\n    SOA\t6\tmarks the start of a zone of authority\t[RFC1035]\n    7\ta mailbox domain name (EXPERIMENTAL)\t[RFC1035]\n    MG\t8\ta mail group member (EXPERIMENTAL)\t[RFC1035]\n    MR\t9\ta mail rename domain name (EXPERIMENTAL)\t[RFC1035]\n    NULL\t10\ta null RR (EXPERIMENTAL)\t[RFC1035]\n    WKS\t11\ta well known service description\t[RFC1035]\n    PTR\t12\ta domain name pointer\t[RFC1035]\n    HINFO\t13\thost information\t[RFC1035]\n    MINFO\t14\tmailbox or mail list information\t[RFC1035]\n    MX\t15\tmail exchange\t[RFC1035]\n    TXT\t16\ttext strings\t[RFC1035]\n    RP\t17\tfor Responsible Person\t[RFC1183]\n    AFSDB\t18\tfor AFS Data Base location\t[RFC1183][RFC5864]\n    X25\t19\tfor X.25 PSDN address\t[RFC1183]\n    ISDN\t20\tfor ISDN address\t[RFC1183]\n    RT\t21\tfor Route Through\t[RFC1183]\n    NSAP\t22\tfor NSAP address, NSAP style A record (DEPRECATED)\t[RFC1706][status-change-int-tlds-to-historic]\n    NSAP-PTR\t23\tfor domain name pointer, NSAP style (DEPRECATED)\t[RFC1706][status-change-int-tlds-to-historic]\n    SIG\t24\tfor security signature\t[RFC2536][RFC2931][RFC3110][RFC4034]\n    KEY\t25\tfor security key\t[RFC2536][RFC2539][RFC3110][RFC4034]\n    PX\t26\tX.400 mail mapping information\t[RFC2163]\n    GPOS\t27\tGeographical Position\t[RFC1712]\n    AAAA\t28\tIP6 Address\t[RFC3596]\n    LOC\t29\tLocation Information\t[RFC1876]\n    NXT\t30\tNext Domain (OBSOLETE)\t[RFC2535][RFC3755]\n    EID\t31\tEndpoint Identifier\t[Michael_Patton][http://ana-3.lcs.mit.edu/~jnc/nimrod/dns.txt]\t\t1995-06\n    NIMLOC\t32\tNimrod Locator\t[1][Michael_Patton][http://ana-3.lcs.mit.edu/~jnc/nimrod/dns.txt]\t\t1995-06\n    SRV\t33\tServer Selection\t[1][RFC2782]\n    ATMA\t34\tATM Address\t[ ATM Forum Technical Committee, \"ATM Name System, V2.0\", Doc ID: AF-DANS-0152.000, July 2000. Available from and held in escrow by IANA.]\n    NAPTR\t35\tNaming Authority Pointer\t[RFC3403]\n    KX\t36\tKey Exchanger\t[RFC2230]\n    CERT\t37\tCERT\t[RFC4398]\n    A6\t38\tA6 (OBSOLETE - use AAAA)\t[RFC2874][RFC3226][RFC6563]\n    DNAME\t39\tDNAME\t[RFC6672]\n    SINK\t40\tSINK\t[Donald_E_Eastlake][draft-eastlake-kitchen-sink]\t\t1997-11\n    OPT\t41\tOPT\t[RFC3225][RFC6891]\n    APL\t42\tAPL\t[RFC3123]\n    DS\t43\tDelegation Signer\t[RFC4034]\n    SSHFP\t44\tSSH Key Fingerprint\t[RFC4255]\n    IPSECKEY\t45\tIPSECKEY\t[RFC4025]\n    RRSIG\t46\tRRSIG\t[RFC4034]\n    NSEC\t47\tNSEC\t[RFC4034][RFC9077]\n    DNSKEY\t48\tDNSKEY\t[RFC4034]\n    DHCID\t49\tDHCID\t[RFC4701]\n    NSEC3\t50\tNSEC3\t[RFC5155][RFC9077]\n    NSEC3PARAM\t51\tNSEC3PARAM\t[RFC5155]\n    TLSA\t52\tTLSA\t[RFC6698]\n    SMIMEA\t53\tS/MIME cert association\t[RFC8162]\tSMIMEA/smimea-completed-template\t2015-12-01\n    Unassigned\t54\n    HIP\t55\tHost Identity Protocol\t[RFC8005]\n    NINFO\t56\tNINFO\t[Jim_Reid]\tNINFO/ninfo-completed-template\t2008-01-21\n    RKEY\t57\tRKEY\t[Jim_Reid]\tRKEY/rkey-completed-template\t2008-01-21\n    TALINK\t58\tTrust Anchor LINK\t[Wouter_Wijngaards]\tTALINK/talink-completed-template\t2010-02-17\n    CDS\t59\tChild DS\t[RFC7344]\tCDS/cds-completed-template\t2011-06-06\n    CDNSKEY\t60\tDNSKEY(s) the Child wants reflected in DS\t[RFC7344]\t\t2014-06-16\n    OPENPGPKEY\t61\tOpenPGP Key\t[RFC7929]\tOPENPGPKEY/openpgpkey-completed-template\t2014-08-12\n    CSYNC\t62\tChild-To-Parent Synchronization\t[RFC7477]\t\t2015-01-27\n    ZONEMD\t63\tMessage Digest Over Zone Data\t[RFC8976]\tZONEMD/zonemd-completed-template\t2018-12-12\n    SVCB\t64\tGeneral-purpose service binding\t[RFC9460]\tSVCB/svcb-completed-template\t2020-06-30\n    HTTPS\t65\tSVCB-compatible type for use with HTTP\t[RFC9460]\tHTTPS/https-completed-template\t2020-06-30\n    Unassigned\t66-98\n    SPF\t99\t\t[RFC7208]\n    UINFO\t100\t\t[IANA-Reserved]\n    UID\t101\t\t[IANA-Reserved]\n    GID\t102\t\t[IANA-Reserved]\n    UNSPEC\t103\t\t[IANA-Reserved]\n    NID\t104\t\t[RFC6742]\tILNP/nid-completed-template\n    L32\t105\t\t[RFC6742]\tILNP/l32-completed-template\n    L64\t106\t\t[RFC6742]\tILNP/l64-completed-template\n    LP\t107\t\t[RFC6742]\tILNP/lp-completed-template\n    EUI48\t108\tan EUI-48 address\t[RFC7043]\tEUI48/eui48-completed-template\t2013-03-27\n    EUI64\t109\tan EUI-64 address\t[RFC7043]\tEUI64/eui64-completed-template\t2013-03-27\n    Unassigned\t110-248\n    TKEY\t249\tTransaction Key\t[RFC2930]\n    TSIG\t250\tTransaction Signature\t[RFC8945]\n    IXFR\t251\tincremental transfer\t[RFC1995]\n    AXFR\t252\ttransfer of an entire zone\t[RFC1035][RFC5936]\n    MAILB\t253\tmailbox-related RRs (MB, MG or MR)\t[RFC1035]\n    MAILA\t254\tmail agent RRs (OBSOLETE - see MX)\t[RFC1035]\n    *\t255\tA request for some or all records the server has available\t[RFC1035][RFC6895][RFC8482]\n    URI\t256\tURI\t[RFC7553]\tURI/uri-completed-template\t2011-02-22\n    CAA\t257\tCertification Authority Restriction\t[RFC8659]\tCAA/caa-completed-template\t2011-04-07\n    AVC\t258\tApplication Visibility and Control\t[Wolfgang_Riedel]\tAVC/avc-completed-template\t2016-02-26\n    DOA\t259\tDigital Object Architecture\t[draft-durand-doa-over-dns]\tDOA/doa-completed-template\t2017-08-30\n    AMTRELAY\t260\tAutomatic Multicast Tunneling Relay\t[RFC8777]\tAMTRELAY/amtrelay-completed-template\t2019-02-06\n    RESINFO\t261\tResolver Information as Key/Value Pairs\t[draft-ietf-add-resolver-info-06]\tRESINFO/resinfo-completed-template\t2023-11-02\n    Unassigned\t262-32767\n    TA\t32768\tDNSSEC Trust Authorities\t[Sam_Weiler][http://cameo.library.cmu.edu/][ Deploying DNSSEC Without a Signed Root. Technical Report 1999-19, Information Networking Institute, Carnegie Mellon University, April 2004.]\t\t2005-12-13\n    DLV\t32769\tDNSSEC Lookaside Validation (OBSOLETE)\t[RFC8749][RFC4431]\n    Unassigned\t32770-65279\n    Private use\t65280-65534\n    Reserved\t65535\n\n# Reference\n- [iana](https://www.iana.org/assignments/dns-parameters/dns-parameters.xhtml#dns-parameters-4)\n- [DOMAIN NAMES - IMPLEMENTATION AND SPECIFICATION](https://tools.ietf.org/html/rfc1035)\n- [Domain Name System (DNS) IANA Considerations](https://tools.ietf.org/html/rfc6895)\n- [YANG Types for DNS Classes and Resource Record Types](https://tools.ietf.org/html/rfc9108)","ref":"DNS.ResourceRecordType.html"},{"type":"function","title":"DNS.ResourceRecordType.new/1","doc":"# Create a new Class struct","ref":"DNS.ResourceRecordType.html#new/1"},{"type":"type","title":"DNS.ResourceRecordType.t/0","doc":"","ref":"DNS.ResourceRecordType.html#t:t/0"},{"type":"extras","title":"DNS","doc":"# DNS\n\n[![release](https://github.com/gsmlg-dev/ex_dns/actions/workflows/release.yml/badge.svg)](https://github.com/gsmlg-dev/ex_dns/actions/workflows/release.yml) \n[![Hex.pm](https://img.shields.io/hexpm/v/ex_dns.svg)](https://hex.pm/packages/ex_dns) \n[![Documentation](https://img.shields.io/badge/documentation-gray)](https://hexdocs.pm/ex_dns)\n\n---","ref":"readme.html"},{"type":"extras","title":"Installation - DNS","doc":"The package can be installed by adding `ex_dns` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:ex_dns, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.2"}}